@@ -267,6 +267,7 @@ CREATE TABLE `sim` (
   `auto_reset_remain` int(1) NOT NULL default '0',
   `auto_reset_remain_s` int(11) NOT NULL default '60',
   `last_call_msg` varchar(256) NOT NULL,
+  `count_limit_no_connect` BOOL NOT NULL
   PRIMARY KEY  (`id`),
   KEY `sim_name` (`sim_name`),
   KEY `line_name` (`line_name`)
@@ -364,7 +365,9 @@ CREATE TABLE `system` (
   `auto_disable_asr_threshold` int(11) unsigned NOT NULL default '15',
   `auto_disable_low_acd` tinyint(1) NOT NULL default '0',
   `auto_disable_acd_number` int(11) unsigned NOT NULL default '10',
-  `auto_disable_acd_threshold` int(11) unsigned NOT NULL default '30'
+  `auto_disable_acd_threshold` int(11) unsigned NOT NULL default '30',
+  `auto_reboot_s_call` tinyint(1) NOT NULL,
+  `auto_reboot_s_call_msg` varchar(256) NOT NULL default 'Unassigned (unallocated) number'
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8;
 SET character_set_client = @saved_cs_client;
 
@@ -374,7 +377,7 @@ SET character_set_client = @saved_cs_client;
 
 LOCK TABLES `system` WRITE;
 /*!40000 ALTER TABLE `system` DISABLE KEYS */;
-INSERT INTO `system` VALUES ('Simbank Server',3,1,20,10,110,0,5,0,1,'Unassigned (unallocated) number',0, 10, 15, 0, 10, 30);
+INSERT INTO `system` VALUES ('Simbank Server',3,1,20,10,110,0,5,0,1,'Unassigned (unallocated) number',0, 10, 15, 0, 10, 30, 0, 'Unassigned (unallocated) number');
 /*!40000 ALTER TABLE `system` ENABLE KEYS */;
 UNLOCK TABLES;
 
