@@ -266,7 +266,7 @@
 	@$db->updatequery("ALTER TABLE `system` ADD `warning_remain_count` int(11) NOT NULL default '10'");
         @$db->updatequery("ALTER TABLE `system` ADD `auto_disable_s_call` tinyint(1) NOT NULL");
         @$db->updatequery("ALTER TABLE `system` ADD `auto_disable_s_call_c` int(11) NOT NULL default '1'");
-	@$db->updatequery("ALTER TABLE `system` ADD `auto_disable_s_call_msg` varchar(64) NOT NULL default 'Unassigned (unallocated) number'");
+	@$db->updatequery("ALTER TABLE `system` ADD `auto_disable_s_call_msg` varchar(256) NOT NULL default 'Unassigned (unallocated) number'");
 	@$db->updatequery("ALTER TABLE `system` ADD `auto_disable_low_asr` tinyint(1) NOT NULL default '0'");
 	@$db->updatequery("ALTER TABLE `system` ADD `auto_disable_asr_number` int(11) unsigned NOT NULL default '10'");
 	@$db->updatequery("ALTER TABLE `system` ADD `auto_disable_asr_threshold` int(11) unsigned NOT NULL default '15'");
@@ -346,11 +346,23 @@
 /*1.6.4 add hb fail*/
 	@$db->updatequery("ALTER TABLE  `logs` CHANGE  `value`  `value` INT( 32 ) NOT NULL");
 	if(!$rs || $rs[0] < 110){
-		@$db->updatequery("update `system` set `version`='110'");
 		@$db->updatequery("ALTER TABLE `logs` ADD INDEX (`value`)");
+		@$db->updatequery("update `system` set `version`='110'");
 	}
 	
+/*1.6.5*/
+        @$db->updatequery("ALTER TABLE `system` ADD `auto_reboot_s_call` tinyint(1) NOT NULL");
+	@$db->updatequery("ALTER TABLE `system` ADD `auto_reboot_s_call_msg` varchar(256) NOT NULL default 'Unassigned (unallocated) number'");
+	
+/*1.6.6 add api of get iccid ,imsi and change group; add sim period buffer*/
+	
+/*1.7 fixed memory of xchanged */
+
+/*1.7 add no connected call in call limit */
+	@$db->updatequery("ALTER TABLE  `sim` ADD  `count_limit_no_connect` BOOL NOT NULL");
+/*1.7.2 fixed bug of set fixed IMEI*/
+/*1.7.2-t add dial api*/
+
 	echo "update done! <a href=''  target=_top>Return</a>";
 
-
 ?>
